#!/usr/bin/python
# -*- coding: utf-8 -*-

from Products.zms.zms import ZMS
from Products.zms.zmsdocument import ZMSDocument
from Products.zms.zmsfolder import ZMSFolder
from xml.dom.minidom import *

from org.cmess.c_dom_parser import C_Dom_Parser
from org.cmess.mindmaps.c_zms_mm_converter import C_ZMS_MM_Converter
from org.cmess.mindmaps.c_zms_mm_converter import C_ZMSDocument_MM_Converter
from org.cmess.mindmaps.c_zms_mm_converter import C_ZMSFolder_MM_Converter
from org.cmess.mindmaps.c_zms_mm_converter import C_ZMSGraphic_MM_Converter
from org.cmess.mindmaps.c_zms_mm_converter import C_ZMSTextarea_MM_Converter

class C_Dom_Parser_MM(C_Dom_Parser):
	def __init__(self, context):
		C_Dom_Parser.__init__(self)
		
		if (context is not None and 
				(isinstance(context, ZMS) or isinstance(context, ZMSFolder))):
			self.zms_context	= context
			self.id_array			= context.REQUEST.get('import_nodes', None)
		else:
			self.id_array			= None
			self.zms_context	= None
			
		self.converter_list = {}
		self.mm_version	= None
		
		temp_converter = C_ZMSDocument_MM_Converter(None)
		self.RegisterConverter(temp_converter.GetID(), temp_converter)
		temp_converter = C_ZMSFolder_MM_Converter(None)
		self.RegisterConverter(temp_converter.GetID(), temp_converter)
		#temp_converter = C_ZMSGraphic_MM_Converter(None)
		#self.RegisterConverter(temp_converter.GetID(), temp_converter)
		temp_converter = C_ZMSTextarea_MM_Converter(None)
		self.RegisterConverter(temp_converter.GetID(), temp_converter)
		
	def _ParseNode(self, node, parent_folder, node_id):
		temp_select_value = self.zms_context.REQUEST.get('select_' + node_id, None) 
		
		if (temp_select_value is not None and self.converter_list.has_key(temp_select_value)):
			temp_result = self.converter_list[temp_select_value].ConvertToZMS(node, parent_folder, self.zms_context)
			if (not temp_result.isPage()):
				temp_result = None
		else:
			temp_result = None
			
		return temp_result

	def HandleNodes(self, node, act_parent_folder = None, act_parent_id = None):
		if (self.zms_context is not None):
			if (node is None):
				node = self.root_node
				
			if (act_parent_folder is None):
				act_parent_folder = self.zms_context
				
			act_id = None
				
			while (node is not None):
				if (isinstance(node, xml.dom.minidom.Element)):
					temp_handle_result	= self.HandleOneNode(node, act_parent_folder, act_parent_id, act_id)
					temp_parent_folder	= temp_handle_result[0]
					act_id							= temp_handle_result[2]
					
					if (node.hasChildNodes() and temp_handle_result[3]):
						self.HandleNodes(node.firstChild, 
														(temp_parent_folder is not None and temp_parent_folder.isPage()) and temp_parent_folder or act_parent_folder,
														temp_handle_result[1])

				
				node = node.nextSibling
			
	def HandleOneNode(self, node, act_parent_folder, act_parent_id, act_id):
		#temp_result = (new parent folder, new parent_id, new id, handle subchilds)
		temp_result = (None, act_parent_id, act_id, True)
		
		if (node is not None and isinstance(node, xml.dom.minidom.Element)):
			temp_name = node.nodeName
			
			if (temp_name == 'map'):
				if (node.hasAttribute('version')):
					self.mm_version = node.getAttribute('version')
			elif (temp_name == 'node'):
				if (act_id is None):
					act_id = 0
				else:
					act_id += 1
					
				temp_id = (act_parent_id is not None) and act_parent_id + '_' or ''
				temp_id += '%03d'%(act_id + 1)
				
				if (self.id_array is not None and temp_id in self.id_array):
					temp_result = self._ParseNode(node, act_parent_folder, temp_id)
					temp_result = (temp_result, temp_id, act_id, True)
				else:
					temp_result = (None, act_parent_id, act_id, False)
		
		return temp_result
	
	def RegisterConverter(self, converter_id, convert_obj):
		if (convert_obj is not None and isinstance(convert_obj, C_ZMS_MM_Converter)):
			if (self.converter_list.has_key(converter_id)):
				self.converter_list.update({converter_id : convert_obj})
			else:
				self.converter_list[converter_id] = convert_obj
				
################################################################################

class C_Dom_Parser_MM_Preview(C_Dom_Parser_MM):
	def __init__(self):
		C_Dom_Parser_MM.__init__(self, None)
		
		self.item_list = []
		self.preview_text_length = 50
		
	def _ParseNode(self, node, item_list):
		if (node is not None and node.hasAttribute('TEXT')):
			temp_node_text = node.getAttribute('TEXT')
			if (temp_node_text.find('<html>') < 0):
				if (len(temp_node_text) > self.preview_text_length):
					temp_node_text = temp_node_text[:self.preview_text_length - 3] + '...'
			
				temp_list 			= []
				temp_item_dict	= {'title' : temp_node_text, 'childs' : temp_list}
				item_list.append(temp_item_dict)
			else:
				temp_list = None
		else:
			temp_list = None
		
		return temp_list
	
	def GetConverterTypes(self):
		temp_result = {}
		
		for one_key in self.converter_list.keys():
			temp_result.update({self.converter_list[one_key].GetID() : self.converter_list[one_key].GetType()})
			
		return temp_result
	
	def HandleNodes(self, node, act_item_list = None):
		if (node is None):
			node = self.root_node
			
		if (act_item_list is None):
			act_item_list = self.item_list
			
		while (node is not None):
			if (isinstance(node, xml.dom.minidom.Element)):
				temp_item_list = self.HandleOneNode(node, act_item_list)
				
				if (node.hasChildNodes()):
					if (temp_item_list is None):
						temp_item_list = act_item_list
						
					self.HandleNodes(node.firstChild, temp_item_list)
			
			node = node.nextSibling
			
	def HandleOneNode(self, node, act_parent_folder):
		temp_result = None
		
		if (node is not None and isinstance(node, xml.dom.minidom.Element)):
			temp_name = node.nodeName
			
			if (temp_name == 'map'):
				if (node.hasAttribute('version')):
					self.mm_version = node.getAttribute('version')
			elif (temp_name == 'node'):
					temp_result = self._ParseNode(node, act_parent_folder)
		
		return temp_result
			
	def ReadXMLFile(self, filename):
		C_Dom_Parser.ReadXMLFile(self, filename)
		
		return self.item_list
	
	def SetPreviewTextLength(self, new_length):
		if ((type(new_length) == int) and (new_length > 10)):
			self.preview_text_length = new_length