#!/usr/bin/python
# -*- coding: utf-8 -*-

from Products.zms._zmsglobals import *
from Products.zms.zms import ZMS
from Products.zms.zmsdocument import ZMSDocument
from Products.zms.zmsfolder import ZMSFolder
from Products.zms.zmsobject import ZMSObject
from xml.dom.minidom import *

from org.cmess.c_dom_writer import C_Dom_Writer
from org.cmess.mindmaps.c_zms_mm_converter import C_ZMS_MM_Converter
from org.cmess.mindmaps.c_zms_mm_converter import C_ZMSDocument_MM_Converter
from org.cmess.mindmaps.c_zms_mm_converter import C_ZMSFolder_MM_Converter
from org.cmess.mindmaps.c_zms_mm_converter import C_ZMSGraphic_MM_Converter
from org.cmess.mindmaps.c_zms_mm_converter import C_ZMSTextarea_MM_Converter
from org.cmess.mindmaps.c_zms_mm_converter import C_ZMSZMS_MM_Converter

class C_Dom_Writer_MM(C_Dom_Writer):
	def __init__(self):
		C_Dom_Writer.__init__(self, 'map')
		
		self.root_node.setAttribute('version', '0.8.0')
		
		self.converter_list = {}
		
		temp_converter = C_ZMSDocument_MM_Converter(self.xml_doc)
		self.RegisterConverter(temp_converter.GetID(), temp_converter)
		temp_converter = C_ZMSFolder_MM_Converter(self.xml_doc)
		self.RegisterConverter(temp_converter.GetID(), temp_converter)
		temp_converter = C_ZMSGraphic_MM_Converter(self.xml_doc)
		self.RegisterConverter(temp_converter.GetID(), temp_converter)
		temp_converter = C_ZMSTextarea_MM_Converter(self.xml_doc)
		self.RegisterConverter(temp_converter.GetID(), temp_converter)
		temp_converter = C_ZMSZMS_MM_Converter(self.xml_doc)
		self.RegisterConverter(temp_converter.GetID(), temp_converter)
	
	def _InsertAutoLayout(self, node):
		if (node is not None):
			temp_node = self.xml_doc.createElement('hook')
			temp_node.setAttribute('NAME', 'accessories/plugins/AutomaticLayout.properties')
			
			node.appendChild(temp_node)
			
			temp_result = True
		else:
			temp_result = False
			
		return temp_result
	
	def _InsertElementNode(self, element, parent_node):
		if (element is not None and isinstance(element, ZMSObject) and 
				self.converter_list.has_key(element.meta_id)):
			temp_result = self.converter_list[element.meta_id].ConvertToMM(element, parent_node)
		else:
			temp_result = None
			
		return temp_result
	
	def AddContentToMM(self, context, act_node = None, auto_layout = True):
		if (context is not None and 
				(isinstance(context, ZMS) or isinstance(context, ZMSFolder) or isinstance(context, ZMSDocument)) and
				(not context.isResource(context.REQUEST))):
			if (act_node is None):
				act_node = self.root_node
			
			act_node = self._InsertElementNode(context, act_node)
			
			tempGlobals = ZMSGlobals()

			#don't add childs if there is no parent
			if (act_node is None):
				print ('No converter found for \'' + str(context.getId()) + '\'. Skip this object and his childs.')
			else:
				if (auto_layout):
					auto_layout = not self._InsertAutoLayout(act_node)
				#get all pageelements
				elementChilds = context.filteredChildNodes(context.REQUEST, tempGlobals.PAGEELEMENTS)
				for child in elementChilds:
					self._InsertElementNode(child, act_node) 
			
			#get all subfolders to add items recursiv
			folderChilds = context.filteredChildNodes(context.REQUEST, ['ZMSFolder', 'ZMSDocument'])
			for child in folderChilds:
				self.AddContentToMM(child, act_node, False)

	def GetPrettyXML(self, indent="\t", newline="\n", encoding = None):
		return self.root_node.toprettyxml(indent, newline, encoding)

	def GetXML(self, encoding = None):
		return self.root_node.toxml(encoding)
	
	def RegisterConverter(self, converter_id, convert_obj):
		if (convert_obj is not None and isinstance(convert_obj, C_ZMS_MM_Converter)):
			if (self.converter_list.has_key(converter_id)):
				self.converter_list.update({converter_id : convert_obj})
			else:
				self.converter_list[converter_id] = convert_obj