#!/usr/bin/python
# -*- coding: utf-8 -*-

from Products.zms._zmsglobals import *
from Products.zms.zmsdocument import ZMSDocument
from Products.zms.zmsfolder import ZMSFolder
from Products.zms.zmsgraphic import ZMSGraphic
from Products.zms.zmstextarea import ZMSTextarea
from Products.zms.zms import ZMS
from xml.dom.minidom import *

class C_ZMS_MM_Converter:
	def __init__(self, xml_document):
		self.id 					= None
		self.type					= None
		self.child_types	= None
		
		self.globals = ZMSGlobals()
		self.xml_doc = xml_document
		
	def ConvertToMM(self, element, parent_node):
		return None
	
	def ConvertToZMS(self, xml_node, parent_folder):
		pass
	
	def GetID(self):
		return self.id
	
	def GetType(self):
		return self.type

################################################################################

class C_ZMSDocument_MM_Converter(C_ZMS_MM_Converter):
	def __init__(self, xml_document):
		C_ZMS_MM_Converter.__init__(self, xml_document)
		
		self.id						= 'ZMSDocument'
		self.type					= self.globals.PAGES
		self.child_types	= (self.globals.PAGEELEMENTS, )
		
	def ConvertToMM(self, element, parent_node):
		if (element is not None and isinstance(element, ZMSDocument)):
			temp_node = self.xml_doc.createElement('node')
			
			temp_node.setAttribute('ID', element.getId())
			temp_node.setAttribute('POSITION', 'right')
			temp_node.setAttribute('TEXT', element.getTitlealt(element.REQUEST).decode('utf-8'))
			
			parent_node.appendChild(temp_node)
		else:
			temp_node = None
			
		return temp_node
	
	def ConvertToZMS(self, xml_node, parent_folder, zms_context):
		if (xml_node is not None and xml_node.hasAttribute('TEXT') and parent_folder.isPage()):
			temp_document = parent_folder.manage_addZMSDocument({'id_prefix' : 'e', 
																														'sort_id' : 99999, 
																														'active' : True, 
																														'titleshort_' + zms_context.REQUEST.get('lang', 'ger') : xml_node.getAttribute('TEXT').encode('utf-8'),
																														'title_' + zms_context.REQUEST.get('lang', 'ger') : xml_node.getAttribute('TEXT').encode('utf-8')}, 
																														zms_context.REQUEST)
		else:
			temp_document = None
		
		return temp_document

################################################################################

class C_ZMSFolder_MM_Converter(C_ZMS_MM_Converter):
	def __init__(self, xml_document):
		C_ZMS_MM_Converter.__init__(self, xml_document)
		
		self.id						= 'ZMSFolder'
		self.type					= self.globals.PAGES
		self.child_types	= (self.globals.PAGES, self.globals.PAGEELEMENTS)
		
	def ConvertToMM(self, element, parent_node):
		if (element is not None and isinstance(element, ZMSFolder)):
			temp_node = self.xml_doc.createElement('node')
			
			temp_node.setAttribute('ID', element.getId())
			temp_node.setAttribute('POSITION', 'right')
			temp_node.setAttribute('TEXT', element.getTitlealt(element.REQUEST).decode('utf-8'))
			
			parent_node.appendChild(temp_node)
		else:
			temp_node = None
			
		return temp_node
		
	def ConvertToZMS(self, xml_node, parent_folder, zms_context):
		if (xml_node is not None and xml_node.hasAttribute('TEXT') and parent_folder.isPage()):
			temp_folder = parent_folder.manage_addZMSFolder({'id_prefix' : 'e', 
																												'sort_id' : 99999, 
																												'active' : True, 
																												'titleshort_' + zms_context.REQUEST.get('lang', 'ger') : xml_node.getAttribute('TEXT').encode('utf-8'),
																												'title_' + zms_context.REQUEST.get('lang', 'ger') : xml_node.getAttribute('TEXT').encode('utf-8')}, 
																												zms_context.REQUEST)
		else:
			temp_folder = None
		
		return temp_folder

################################################################################
		
class C_ZMSGraphic_MM_Converter(C_ZMS_MM_Converter):
	def __init__(self, xml_document):
		C_ZMS_MM_Converter.__init__(self, xml_document)
		
		self.id						= 'ZMSGraphic'
		self.type					= self.globals.PAGEELEMENTS
		self.child_types	= ()
		
	def ConvertToMM(self, element, parent_node):
		if (element is not None and isinstance(element, ZMSGraphic)):
			temp_node = self.xml_doc.createElement('node')
			
			temp_node.setAttribute('ID', element.getId())
			temp_node.setAttribute('POSITION', 'right')
			temp_node.setAttribute('TEXT', '<html><img src="' + element.getObjProperty('img', element.REQUEST).getHref(element.REQUEST) + '">')
			
			parent_node.appendChild(temp_node)
		else:
			temp_node = None
			
		return temp_node

################################################################################

class C_ZMSTextarea_MM_Converter(C_ZMS_MM_Converter):
	def __init__(self, xml_document):
		C_ZMS_MM_Converter.__init__(self, xml_document)
		
		self.id 					= 'ZMSTextarea'
		self.type					= self.globals.PAGEELEMENTS
		self.child_types	= ()
		
	def ConvertToMM(self, element, parent_node):
		if (element is not None and isinstance(element, ZMSTextarea)):
			temp_node = self.xml_doc.createElement('node')
			
			temp_node.setAttribute('ID', element.getId())
			temp_node.setAttribute('POSITION', 'right')
			temp_node.setAttribute('TEXT', element.getText(element.REQUEST).decode('utf-8'))
			
			parent_node.appendChild(temp_node)
		else:
			temp_node = None
			
		return temp_node
			
	def ConvertToZMS(self, xml_node, parent_folder, zms_context):
		if (xml_node is not None and xml_node.hasAttribute('TEXT') and parent_folder.isPage()):
			temp_textarea = parent_folder.manage_addZMSTextarea({'id_prefix' : 'e', 
																														'sort_id' : 99999, 
																														'active' : True, 
																														'text_' + zms_context.REQUEST.get('lang', 'ger') : xml_node.getAttribute('TEXT').encode('utf-8')}, 
																														zms_context.REQUEST)
		else:
			temp_textarea = None
		
		return temp_textarea

################################################################################

class C_ZMSZMS_MM_Converter(C_ZMS_MM_Converter):
	def __init__(self, xml_document):
		C_ZMS_MM_Converter.__init__(self, xml_document)
		
		self.id 					= 'ZMS'
		self.type					= self.globals.PAGES
		self.child_types	= (self.globals.PAGES, self.globals.PAGEELEMENTS)
		
	def ConvertToMM(self, element, parent_node):
		if (element is not None and isinstance(element, ZMS)):
			temp_node = self.xml_doc.createElement('node')
			
			temp_node.setAttribute('ID', element.getId())
			temp_node.setAttribute('POSITION', 'right')
			temp_node.setAttribute('TEXT', element.getTitlealt(element.REQUEST).decode('utf-8'))
			
			parent_node.appendChild(temp_node)
		else:
			temp_node = None
			
		return temp_node